Class: Aws::ApiGatewayManagementApi::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ApiGatewayManagementApi::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-apigatewaymanagementapi/client.rb
Overview
An API client for ApiGatewayManagementApi. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ApiGatewayManagementApi::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#delete_connection(params = {}) ⇒ Struct
Delete the connection with the provided id.
-
#get_connection(params = {}) ⇒ Types::GetConnectionResponse
Get information about the connection with the provided id.
-
#post_to_connection(params = {}) ⇒ Struct
Sends the provided data to the specified connection.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-apigatewaymanagementapi/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
580 581 582 |
# File 'lib/aws-sdk-apigatewaymanagementapi/client.rb', line 580 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
583 584 585 |
# File 'lib/aws-sdk-apigatewaymanagementapi/client.rb', line 583 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 |
# File 'lib/aws-sdk-apigatewaymanagementapi/client.rb', line 553 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ApiGatewayManagementApi') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-apigatewaymanagementapi' context[:gem_version] = '1.75.0' Seahorse::Client::Request.new(handlers, context) end |
#delete_connection(params = {}) ⇒ Struct
Delete the connection with the provided id.
491 492 493 494 |
# File 'lib/aws-sdk-apigatewaymanagementapi/client.rb', line 491 def delete_connection(params = {}, = {}) req = build_request(:delete_connection, params) req.send_request() end |
#get_connection(params = {}) ⇒ Types::GetConnectionResponse
Get information about the connection with the provided id.
521 522 523 524 |
# File 'lib/aws-sdk-apigatewaymanagementapi/client.rb', line 521 def get_connection(params = {}, = {}) req = build_request(:get_connection, params) req.send_request() end |
#post_to_connection(params = {}) ⇒ Struct
Sends the provided data to the specified connection.
544 545 546 547 |
# File 'lib/aws-sdk-apigatewaymanagementapi/client.rb', line 544 def post_to_connection(params = {}, = {}) req = build_request(:post_to_connection, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
573 574 575 |
# File 'lib/aws-sdk-apigatewaymanagementapi/client.rb', line 573 def waiter_names [] end |